//-------------------------------------------------------------------------------
// DBFood
//-------------------------------------------------------------------------------

datablock StaticShapeData(DBFood : DBObject)
{
   // The category variable determines where the item
   // shows up in the mission editor's creator tree.
   // Path is relative to where the script is executed from.
   category = "Restaurant";
   shapeFile = "~/data/shapes/restaurant/lobster_thermodor/lobster.dts";
   bitmap = "";
   nextBiteDB = DBPlate;
   soundEat = "~/data/sound/cogmac/aud_chomp.wav";
   soundTouch = "~/data/sound/cogmac/plate.wav";
   touchRot = 0.32;
   isEmpty = false;
};

function DBFood::onAdd(%this, %obj) { DBObject::OnAdd(%this, %obj); }
function DBFood::OnPickup( %this, %client, %user, %obj ) { DBObject::OnPickup( %this, %client, %user, %obj ); }
function DBFood::OnPutDown( %this, %client, %user, %obj, %surface, %pos, %ignore ) { DBObject::OnPutDown( %this, %client, %user, %obj, %surface, %pos, %ignore ); }
function DBFood::OnLookAt( %this, %client, %obj ) { DBObject::OnLookAt( %this, %client, %obj ); }
function DBFood::OnGive( %this, %client, %user, %obj, %target, %pos ) { DBObject::OnGive( %this, %client, %user, %obj, %target, %pos ); }
function DBFood::OnSit( %this, %client, %user, %obj ) { DBObject::OnSit( %this, %client, %user, %obj ); }
function DBFood::OnTouch( %this, %client, %user, %obj ) { DBObject::OnTouch( %this, %client, %user, %obj ); }

function DBFood::OnEat( %this, %client, %obj )
{
   COGLOG_STATECHANGE( %client.player, "ATPOS", COGLOG_POS(%client.player.getPosition()) );
   COGLOG_ACTION( %client.player, "EAT", %obj );

   if( %this.nextBiteDB !$= %obj.getDatablock().getName() )
   {
      COGLOG_STATECHANGE( %obj, "CLASS", %this.nextBiteDB );
   }
   %obj.setDataBlock( %this.nextBiteDB );

   // Play an eating sound.
   PlaySound( %this.soundEat, %obj.getPosition() );

   if( %obj.getDataBlock().isEmpty == true )
   {
      if( %obj.getDataBlock().isBeverage == true )
      {
         %count = ClientGroup.getCount();
         for ( %i = 0; %i < %count; %i++ )
         {
            %other = ClientGroup.getObject( %i );
            if( %other != %client ) break;
         }
         if( %other == %client ) %other = null;
         SetNarration( %other, "[Your" SPC %obj.getDataBlock().noun SPC "is empty.]" );
      }
      COGLOG_STATECHANGE( %obj, "ISEMPTY", "TRUE" );
   }

   // Remove dirty things that are eaten completely.
   if( %obj.getDataBlock().isDirty && %obj.getDataBlock().isEmpty && ( !%obj.isMounted() ) )
   {
      %surface = FindSurface( %obj );
      if( %surface.getDataBlock().cleansDirty )
      {
         // Take much longer to clean an item that was eaten on the counter.
         schedule( 40000, 0, CleanItem, %obj );
      }
   }
}

//-------------------------------------------------------------------------------

datablock StaticShapeData(DBSoup : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/soup/soup.dts";
   bitmap = "restaurant/data/shapes/restaurant/soup/soup.bmp";
   nextBiteDB = DBSoup_Bite1;
   soundEat = "~/data/sound/cogmac/slurp.wav";
   noun = "soup";
};

datablock StaticShapeData(DBSoup_Bite1 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/soup/soup_bite1.dts";
   bitmap = "restaurant/data/shapes/restaurant/soup/soup.bmp";
   nextBiteDB = DBSoup_Bite2;
   soundEat = "~/data/sound/cogmac/slurp.wav";
   isDirty = true;
   noun = "soup";
};

datablock StaticShapeData(DBSoup_Bite2 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/soup/soup_bite2.dts";
   bitmap = "restaurant/data/shapes/restaurant/soup/soup.bmp";
   nextBiteDB = DBBowl;
   soundEat = "~/data/sound/cogmac/slurp.wav";
   isDirty = true;
   noun = "soup";
};

datablock StaticShapeData(DBSalad : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/chef_salad/chef_salad.dts";
   bitmap = "restaurant/data/shapes/restaurant/chef_salad/chef_salad.bmp";
   nextBiteDB = DBSalad_Bite1;
   noun = "salad";
};

datablock StaticShapeData(DBSalad_Bite1 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/chef_salad/chef_salad_bite1.dts";
   bitmap = "restaurant/data/shapes/restaurant/chef_salad/chef_salad.bmp";
   nextBiteDB = DBSalad_Bite2;
   isDirty = true;
   noun = "salad";
};

datablock StaticShapeData(DBSalad_Bite2 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/chef_salad/chef_salad_bite2.dts";
   bitmap = "restaurant/data/shapes/restaurant/chef_salad/chef_salad.bmp";
   nextBiteDB = DBPlate;
   isDirty = true;
   noun = "salad";
};

datablock StaticShapeData(DBSalad_Bite3 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/chef_salad/chef_salad_bite3.dts";
   bitmap = "restaurant/data/shapes/restaurant/chef_salad/chef_salad.bmp";
   nextBiteDB = DBPlate;
   isDirty = true;
   noun = "salad";
};

datablock StaticShapeData(DBLobster : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/lobster_thermodor/lobster.dts";
   bitmap = "restaurant/data/shapes/restaurant/lobster_thermodor/lobster.bmp";
   nextBiteDB = DBLobster_Bite1;
   noun = "lobster";
};

datablock StaticShapeData(DBLobster_Bite1 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/lobster_thermodor/lobster_bite1.dts";
   bitmap = "restaurant/data/shapes/restaurant/lobster_thermodor/lobster.bmp";
   nextBiteDB = DBLobster_Bite2;
   isDirty = true;
   noun = "lobster";
};

datablock StaticShapeData(DBLobster_Bite2 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/lobster_thermodor/lobster_bite2.dts";
   bitmap = "restaurant/data/shapes/restaurant/lobster_thermodor/lobster.bmp";
   nextBiteDB = DBPlate;
   isDirty = true;
   noun = "lobster";
};

datablock StaticShapeData(DBFilet : DBFood)
{
   className = "DBFood";
   nextBiteDB = DBFilet_Bite1;
   shapeFile = "~/data/shapes/restaurant/filet/filet.dts";
   bitmap = "restaurant/data/shapes/restaurant/filet/filet.bmp";
   noun = "steak";
};

datablock StaticShapeData(DBFilet_Bite1 : DBFood)
{
   className = "DBFood";
   nextBiteDB = DBFilet_Bite2;
   shapeFile = "~/data/shapes/restaurant/filet/filet_bite1.dts";
   bitmap = "restaurant/data/shapes/restaurant/filet/filet.bmp";
   isDirty = true;
   noun = "steak";
};

datablock StaticShapeData(DBFilet_Bite2 : DBFood)
{
   className = "DBFood";
   nextBiteDB = DBPlate;
   shapeFile = "~/data/shapes/restaurant/filet/filet_bite2.dts";
   bitmap = "restaurant/data/shapes/restaurant/filet/filet.bmp";
   isDirty = true;
   noun = "steak";
};

datablock StaticShapeData(DBSpaghetti : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/spagetti/spagetti.dts";
   bitmap = "restaurant/data/shapes/restaurant/spagetti/spagetti.bmp";
   nextBiteDB = DBSpaghetti_Bite1;
   noun = "spaghetti";
};

datablock StaticShapeData(DBSpaghetti_Bite1 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/spagetti/spagetti_bite1.dts";
   bitmap = "restaurant/data/shapes/restaurant/spagetti/spagetti.bmp";
   nextBiteDB = DBSpaghetti_Bite2;
   isDirty = true;
   noun = "spaghetti";
};

datablock StaticShapeData(DBSpaghetti_Bite2 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/spagetti/spagetti_bite2.dts";
   bitmap = "restaurant/data/shapes/restaurant/spagetti/spagetti.bmp";
   nextBiteDB = DBPlate;
   isDirty = true;
   noun = "spaghetti";
};

datablock StaticShapeData(DBSalmon : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/salmon/salmon.dts";
   bitmap = "restaurant/data/shapes/restaurant/salmon/salmon.bmp";
   nextBiteDB = DBSalmon_Bite1;
   noun = "salmon";
};

datablock StaticShapeData(DBSalmon_Bite1 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/salmon/salmon_bite1.dts";
   bitmap = "restaurant/data/shapes/restaurant/salmon/salmon.bmp";
   nextBiteDB = DBSalmon_Bite2;
   isDirty = true;
   noun = "salmon";
};

datablock StaticShapeData(DBSalmon_Bite2 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/salmon/salmon_bite2.dts";
   bitmap = "restaurant/data/shapes/restaurant/salmon/salmon.bmp";
   nextBiteDB = DBPlate;
   isDirty = true;
   noun = "salmon";
};

datablock StaticShapeData(DBSalmon_Bite3 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/salmon/salmon_bite3.dts";
   bitmap = "restaurant/data/shapes/restaurant/salmon/salmon.bmp";
   nextBiteDB = DBPlate;
   isDirty = true;
   noun = "salmon";
};

datablock StaticShapeData(DBCheesecake : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/cheesecake/cheesecake.dts";
   bitmap = "restaurant/data/shapes/restaurant/cheesecake/cheesecake.bmp";
   nextBiteDB = DBCheesecake_Bite1;
   noun = "cheesecake";
};

datablock StaticShapeData(DBCheesecake_Bite1 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/cheesecake/cheesecake_bite1.dts";
   bitmap = "restaurant/data/shapes/restaurant/cheesecake/cheesecake.bmp";
   nextBiteDB = DBCheesecake_Bite2;
   isDirty = true;
   noun = "cheesecake";
};

datablock StaticShapeData(DBCheesecake_Bite2 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/cheesecake/cheesecake_bite2.dts";
   bitmap = "restaurant/data/shapes/restaurant/cheesecake/cheesecake.bmp";
   nextBiteDB = DBPlate;
   isDirty = true;
   noun = "cheesecake";
};

datablock StaticShapeData(DBPie : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/pie/pie.dts";
   bitmap = "restaurant/data/shapes/restaurant/pie/pie.bmp";
   nextBiteDB = DBPie_Bite1;
   noun = "pie";
};

datablock StaticShapeData(DBPie_Bite1 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/pie/pie_bite1.dts";
   bitmap = "restaurant/data/shapes/restaurant/pie/pie.bmp";
   nextBiteDB = DBPie_Bite2;
   isDirty = true;
   noun = "pie";
};

datablock StaticShapeData(DBPie_Bite2 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/pie/pie_bite2.dts";
   bitmap = "restaurant/data/shapes/restaurant/pie/pie.bmp";
   nextBiteDB = DBPlate;
   isDirty = true;
   noun = "pie";
};

datablock StaticShapeData(DBTart : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/tart/tart.dts";
   bitmap = "restaurant/data/shapes/restaurant/tart/tart.bmp";
   nextBiteDB = DBTart_Bite1;
   noun = "tart";
};

datablock StaticShapeData(DBTart_Bite1 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/tart/tart_bite1.dts";
   bitmap = "restaurant/data/shapes/restaurant/tart/tart.bmp";
   nextBiteDB = DBTart_Bite2;
   isDirty = true;
   noun = "tart";
};

datablock StaticShapeData(DBTart_Bite2 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/tart/tart_bite2.dts";
   bitmap = "restaurant/data/shapes/restaurant/tart/tart.bmp";
   nextBiteDB = DBPlate;
   isDirty = true;
   noun = "tart";
};

datablock StaticShapeData(DBWhiteWine : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/white_wine/white_wine.dts";
   bitmap = "restaurant/data/shapes/restaurant/red_wine/wine_glass.bmp";
   soundEat = "~/data/sound/cogmac/slurp.wav";
   soundTouch = "~/data/sound/cogmac/glass.wav";
   nextBiteDB = DBWhiteWine_Bite1;
   noun = "wine";
};

datablock StaticShapeData(DBWhiteWine_Bite1 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/white_wine/white_wine_bite1.dts";
   bitmap = "restaurant/data/shapes/restaurant/red_wine/wine_glass.bmp";
   soundEat = "~/data/sound/cogmac/slurp.wav";
   soundTouch = "~/data/sound/cogmac/glass.wav";
   nextBiteDB = DBWhiteWine_Bite2;
   isDirty = true;
   noun = "wine";
};

datablock StaticShapeData(DBWhiteWine_Bite2 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/white_wine/white_wine_bite2.dts";
   bitmap = "restaurant/data/shapes/restaurant/red_wine/wine_glass.bmp";
   soundEat = "~/data/sound/cogmac/slurp.wav";
   soundTouch = "~/data/sound/cogmac/glass.wav";
   nextBiteDB = DBWineGlass;
   isDirty = true;
   noun = "wine";
};

datablock StaticShapeData(DBRedWine : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/red_wine/red_wine.dts";
   bitmap = "restaurant/data/shapes/restaurant/red_wine/wine_glass.bmp";
   soundEat = "~/data/sound/cogmac/slurp.wav";
   soundTouch = "~/data/sound/cogmac/glass.wav";
   nextBiteDB = DBRedWine_Bite1;
   noun = "wine";
};

datablock StaticShapeData(DBRedWine_Bite1 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/red_wine/red_wine_bite1.dts";
   bitmap = "restaurant/data/shapes/restaurant/red_wine/wine_glass.bmp";
   soundEat = "~/data/sound/cogmac/slurp.wav";
   soundTouch = "~/data/sound/cogmac/glass.wav";
   nextBiteDB = DBRedWine_Bite2;
   isDirty = true;
   noun = "wine";
};

datablock StaticShapeData(DBRedWine_Bite2 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/red_wine/red_wine_bite2.dts";
   bitmap = "restaurant/data/shapes/restaurant/red_wine/wine_glass.bmp";
   soundEat = "~/data/sound/cogmac/slurp.wav";
   soundTouch = "~/data/sound/cogmac/glass.wav";
   nextBiteDB = DBWineGlass;
   isDirty = true;
   noun = "wine";
};

datablock StaticShapeData(DBBeerGlass : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/beer/beer_glass.dts";
   bitmap = "restaurant/data/shapes/restaurant/glass/glass.bmp";
   soundEat = "~/data/sound/cogmac/slurp.wav";
   soundTouch = "~/data/sound/cogmac/glass.wav";
   nextBiteDB = DBBeerGlass_Bite1;
   noun = "beer";
};

datablock StaticShapeData(DBBeerGlass_Bite1 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/beer/beer_glass_bite1.dts";
   bitmap = "restaurant/data/shapes/restaurant/glass/glass.bmp";
   soundEat = "~/data/sound/cogmac/slurp.wav";
   soundTouch = "~/data/sound/cogmac/glass.wav";
   nextBiteDB = DBBeerGlass_Bite2;
   isDirty = true;
   noun = "beer";
};

datablock StaticShapeData(DBBeerGlass_Bite2 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/beer/beer_glass_bite2.dts";
   bitmap = "restaurant/data/shapes/restaurant/glass/glass.bmp";
   soundEat = "~/data/sound/cogmac/slurp.wav";
   soundTouch = "~/data/sound/cogmac/glass.wav";
   nextBiteDB = DBGlass;
   isDirty = true;
   noun = "beer";
};

datablock StaticShapeData(DBWater : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/water/water.dts";
   bitmap = "restaurant/data/shapes/restaurant/glass/glass.bmp";
   soundEat = "~/data/sound/cogmac/slurp.wav";
   soundTouch = "~/data/sound/cogmac/glass.wav";
   nextBiteDB = DBWater_Bite1;
   noun = "water";
};

datablock StaticShapeData(DBWater_Bite1 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/water/water_bite1.dts";
   bitmap = "restaurant/data/shapes/restaurant/glass/glass.bmp";
   soundEat = "~/data/sound/cogmac/slurp.wav";
   soundTouch = "~/data/sound/cogmac/glass.wav";
   nextBiteDB = DBWater_Bite2;
   isDirty = true;
   noun = "water";
};

datablock StaticShapeData(DBWater_Bite2 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/water/water_bite2.dts";
   bitmap = "restaurant/data/shapes/restaurant/glass/glass.bmp";
   soundEat = "~/data/sound/cogmac/slurp.wav";
   soundTouch = "~/data/sound/cogmac/glass.wav";
   nextBiteDB = DBGlass;
   isDirty = true;
   noun = "water";
};

datablock StaticShapeData(DBFlower : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/bud_vase/bud_vase.dts";
   bitmap = "restaurant/data/shapes/restaurant/bud_vase/bud_vase.bmp";
   soundTouch = "~/data/sound/cogmac/glass.wav";
   nextBiteDB = DBVase;
   noun = "flower";
};

datablock StaticShapeData(DBTrash : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/trash_can/trash_can.dts";
   bitmap = "restaurant/data/shapes/restaurant/trash_can/trash_can.bmp";
   soundTouch = "~/data/sound/cogmac/flies.wav";
   nextBiteDB = DBTrash_Bite1;
   noun = "trash";
};

datablock StaticShapeData(DBTrash_Bite1 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/trash_can/trash_can_bite1.dts";
   bitmap = "restaurant/data/shapes/restaurant/trash_can/trash_can.bmp";
   soundTouch = "~/data/sound/cogmac/flies.wav";
   nextBiteDB = DBTrash_Bite2;
   noun = "trash";
};

datablock StaticShapeData(DBTrash_Bite2 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/trash_can/trash_can_bite2.dts";
   bitmap = "restaurant/data/shapes/restaurant/trash_can/trash_can.bmp";
   soundTouch = "~/data/sound/cogmac/flies.wav";
   nextBiteDB = DBTrash_Empty;
   noun = "trash";
};

datablock StaticShapeData(DBFruit : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/fruit/fruit.dts";
   bitmap = "restaurant/data/shapes/restaurant/fruit/fruit.bmp";
   soundTouch = "~/data/sound/cogmac/plate.wav";
   touchRot = 0.32;
   nextBiteDB = DBFruit_Bite1;
   noun = "fruit";
};

datablock StaticShapeData(DBFruit_Bite1 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/fruit/fruit_bite1.dts";
   bitmap = "restaurant/data/shapes/restaurant/fruit/fruit.bmp";
   soundTouch = "~/data/sound/cogmac/plate.wav";
   touchRot = 0.32;
   nextBiteDB = DBFruit_Bite2;
   noun = "fruit";
};

datablock StaticShapeData(DBFruit_Bite2 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/fruit/fruit_bite2.dts";
   bitmap = "restaurant/data/shapes/restaurant/fruit/fruit.bmp";
   soundTouch = "~/data/sound/cogmac/plate.wav";
   touchRot = 0.32;
   nextBiteDB = DBFruit_Bowl;
   noun = "fruit";
};

datablock StaticShapeData(DBFoodPrep : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/food_prep/food_prep.dts";
   bitmap = "restaurant/data/shapes/restaurant/food_prep/food_prep.bmp";
   soundTouch = "~/data/sound/cogmac/chop2.wav";
   nextBiteDB = DBFoodPrep_Bite1;
   noun = "food";
};

datablock StaticShapeData(DBFoodPrep_Bite1 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/food_prep/food_prep_bite1.dts";
   bitmap = "restaurant/data/shapes/restaurant/food_prep/food_prep.bmp";
   soundTouch = "~/data/sound/cogmac/chop2.wav";
   nextBiteDB = DBFoodPrep_Bite2;
   noun = "food";
};

datablock StaticShapeData(DBFoodPrep_Bite2 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/food_prep/food_prep_bite2.dts";
   bitmap = "restaurant/data/shapes/restaurant/food_prep/food_prep.bmp";
   soundTouch = "~/data/sound/cogmac/chop2.wav";
   nextBiteDB = DBFoodPrep_Empty;
   noun = "food";
};

datablock StaticShapeData(DBCoffee : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/coffee/coffee.dts";
   bitmap = "restaurant/data/shapes/restaurant/coffee/coffee.bmp";
   soundEat = "~/data/sound/cogmac/slurp.wav";
   soundTouch = "~/data/sound/cogmac/plate.wav";
   nextBiteDB = DBCoffee_Bite1;
   noun = "coffee";
};

datablock StaticShapeData(DBCoffee_Bite1 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/coffee/coffee_bite1.dts";
   bitmap = "restaurant/data/shapes/restaurant/coffee/coffee.bmp";
   soundEat = "~/data/sound/cogmac/slurp.wav";
   soundTouch = "~/data/sound/cogmac/plate.wav";
   nextBiteDB = DBCoffee_Bite2;
   isDirty = true;
   noun = "coffee";
};

datablock StaticShapeData(DBCoffee_Bite2 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/coffee/coffee_bite2.dts";
   bitmap = "restaurant/data/shapes/restaurant/coffee/coffee.bmp";
   soundEat = "~/data/sound/cogmac/slurp.wav";
   soundTouch = "~/data/sound/cogmac/plate.wav";
   nextBiteDB = DBMug;
   isDirty = true;
   noun = "coffee";
};

datablock StaticShapeData(DBTea : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/tea/tea.dts";
   bitmap = "restaurant/data/shapes/restaurant/tea/tea.bmp";
   soundEat = "~/data/sound/cogmac/slurp.wav";
   soundTouch = "~/data/sound/cogmac/plate.wav";
   nextBiteDB = DBTea_Bite1;
   noun = "tea";
};

datablock StaticShapeData(DBTea_Bite1 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/tea/tea_bite1.dts";
   bitmap = "restaurant/data/shapes/restaurant/tea/tea.bmp";
   soundEat = "~/data/sound/cogmac/slurp.wav";
   soundTouch = "~/data/sound/cogmac/plate.wav";
   nextBiteDB = DBTea_Bite2;
   isDirty = true;
   noun = "tea";
};

datablock StaticShapeData(DBTea_Bite2 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/tea/tea_bite2.dts";
   bitmap = "restaurant/data/shapes/restaurant/tea/tea.bmp";
   soundEat = "~/data/sound/cogmac/slurp.wav";
   soundTouch = "~/data/sound/cogmac/plate.wav";
   nextBiteDB = DBTeaCup;
   isDirty = true;
   noun = "tea";
};

datablock StaticShapeData(DBWine : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/wine/wine.dts";
   bitmap = "restaurant/data/shapes/restaurant/wine/wine.bmp";
   soundTouch = "~/data/sound/cogmac/uncork.wav";
   soundEat = "~/data/sound/cogmac/slurp.wav";
   touchRot = 0.32;
   nextBiteDB = DBWine_Bite1;
   noun = "wine";
};

datablock StaticShapeData(DBWine_Bite1 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/wine/wine.dts";
   bitmap = "restaurant/data/shapes/restaurant/wine/wine.bmp";
   soundTouch = "~/data/sound/cogmac/uncork.wav";
   soundEat = "~/data/sound/cogmac/slurp.wav";
   touchRot = 0.32;
   nextBiteDB = DBWine_Bite2;
   isDirty = true;
   noun = "wine";
};

datablock StaticShapeData(DBWine_Bite2 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/wine/wine.dts";
   bitmap = "restaurant/data/shapes/restaurant/wine/wine.bmp";
   soundTouch = "~/data/sound/cogmac/uncork.wav";
   soundEat = "~/data/sound/cogmac/slurp.wav";
   touchRot = 0.32;
   nextBiteDB = DBWine_Empty;
   isDirty = true;
   noun = "wine";
};

datablock StaticShapeData(DBBottle : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/bottle/bottle.dts";
   bitmap = "restaurant/data/shapes/restaurant/bottle/bottle.bmp";
   soundTouch = "~/data/sound/cogmac/water2.wav";
   soundEat = "~/data/sound/cogmac/slurp.wav";
   touchRot = 0.32;
   nextBiteDB = DBBottle_Bite1;
   noun = "water";
};

datablock StaticShapeData(DBBottle_Bite1 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/bottle/bottle.dts";
   bitmap = "restaurant/data/shapes/restaurant/bottle/bottle.bmp";
   soundTouch = "~/data/sound/cogmac/water2.wav";
   soundEat = "~/data/sound/cogmac/slurp.wav";
   touchRot = 0.32;
   nextBiteDB = DBBottle_Bite2;
   isDirty = true;
   noun = "water";
};

datablock StaticShapeData(DBBottle_Bite2 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/bottle/bottle.dts";
   bitmap = "restaurant/data/shapes/restaurant/bottle/bottle.bmp";
   soundTouch = "~/data/sound/cogmac/water2.wav";
   soundEat = "~/data/sound/cogmac/slurp.wav";
   touchRot = 0.32;
   nextBiteDB = DBBottle_Empty;
   isDirty = true;
   noun = "water";
};

datablock StaticShapeData(DBBrandy : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/brandy_bottle/brandy_bottle.dts";
   bitmap = "restaurant/data/shapes/restaurant/brandy_bottle/brandy_bottle.bmp";
   soundTouch = "~/data/sound/cogmac/glass.wav";
   soundEat = "~/data/sound/cogmac/slurp.wav";
   touchRot = 0.32;
   nextBiteDB = DBBrandy_Bite1;
   noun = "brandy";
};

datablock StaticShapeData(DBBrandy_Bite1 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/brandy_bottle/brandy_bottle.dts";
   bitmap = "restaurant/data/shapes/restaurant/brandy_bottle/brandy_bottle.bmp";
   soundTouch = "~/data/sound/cogmac/glass.wav";
   soundEat = "~/data/sound/cogmac/slurp.wav";
   touchRot = 0.32;
   nextBiteDB = DBBrandy_Bite2;
   isDirty = true;
   noun = "brandy";
};

datablock StaticShapeData(DBBrandy_Bite2 : DBFood)
{
   className = "DBFood";
   shapeFile = "~/data/shapes/restaurant/brandy_bottle/brandy_bottle.dts";
   bitmap = "restaurant/data/shapes/restaurant/brandy_bottle/brandy_bottle.bmp";
   soundTouch = "~/data/sound/cogmac/glass.wav";
   soundEat = "~/data/sound/cogmac/slurp.wav";
   touchRot = 0.32;
   nextBiteDB = DBBrandy_Empty;
   isDirty = true;
   noun = "brandy";
};




